@@ -6,14 +6,11 @@ use warnings;
 use 5.010;
 require feature;
 
-our $VERSION = 0.06;
+our $VERSION = 0.07;
 require XSLoader;
 
 XSLoader::load('Mojo::Base::XS', $VERSION);
 
-newxs_attr(__PACKAGE__ . '::attr');
-newxs_constructor(__PACKAGE__ . '::new');
-
 my $base_infected;
 
 sub import {
